@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
-# (c) 2015-2016 Andreas Motl, Elmyra UG <andreas.motl@elmyra.de>
+# (c) 2015-2021 Andreas Motl <andreas.motl@getkotori.org>
 from bunch import Bunch
 from twisted.logger import Logger
 from kotori.daq.services import RootService
 from kotori.daq.services.mig import MqttInfluxGrafanaService
-from kotori.daq.intercom.strategies import WanBusStrategy
+from kotori.daq.strategy.wan import WanBusStrategy
 from kotori.daq.graphing.grafana.manager import GrafanaManager
 
 log = Logger()
 
+
 class MqttKitApplication(RootService):
     """
     Application service container root object
@@ -27,8 +28,8 @@ class MqttKitApplication(RootService):
         service = MqttInfluxGrafanaService(
             channel  = self.channel,
             # Data processing strategy and graphing components
-            strategy = WanBusStrategy(),
-            graphing = GrafanaManager(settings=global_settings, channel=self.channel)
+            strategy=WanBusStrategy(),
+            graphing=GrafanaManager(settings=global_settings, channel=self.channel)
             )
 
         # Register service component with its container
